import { SearchSpec, Search } from '@wix/sdk-types';

/**
 * A billable item represents a billable product or service that can be added to invoices.
 * You can create, manage, and organize these items to streamline your billing process.
 * Billable items include details like name, description, price, and tax information.
 */
interface BillableItem {
    /**
     * Billable item ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the billable item is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the billable item.
     *
     * Ignored when creating a billable item.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the billable item was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the billable item was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * The name or title of the billable item. Used to identify the item on an invoice and display to customers.
     * @minLength 1
     * @maxLength 200
     */
    name?: string;
    /**
     * Detailed description of the billable item. Provides additional information about the product or service.
     * @minLength 1
     * @maxLength 600
     */
    description?: string | null;
    /**
     * Price of the billable item in decimal format with up to 4 decimal places.
     * Represents the base cost before taxes are applied. This is a required field when creating a new billable item.
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:-1000000000000000, lte:1000000000000000, maxScale:4 }
     */
    price?: string;
    /**
     * Reference to a tax group that defines the tax rules applicable to this billable item.
     * Use the Tax Groups API to retrieve available tax groups for the business.
     * The tax group determines how taxes are calculated when this item is added to an invoice.
     * If not specified, the default tax rules for the business will apply.
     * See: https://dev.wix.com/docs/rest/business-solutions/e-commerce/tax/tax-groups/introduction
     * @format GUID
     */
    taxGroupId?: string | null;
    /**
     * The billable item image. Optional visual representation of the product or service.
     * Image must be uploaded to Wix Media Manager before referencing here.
     * Contains image ID, URL, dimensions, and alt text for accessibility.
     * To upload an image, use the Media Manager API or dashboard before creating/updating the BillableItem.
     */
    image?: string;
    /**
     * Custom field data for the billable item.
     * Extended fields must be configured in the app dashboard before they can be accessed with API calls.
     */
    extendedFields?: ExtendedFields;
    /** Tags. */
    tags?: Tags;
}
interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
/**
 * Common object for tags.
 * Should be use as in this example:
 * message Foo {
 * string id = 1;
 * ...
 * Tags tags = 5
 * }
 *
 * example of taggable entity
 * {
 * id: "123"
 * tags: {
 * tags: {
 * tag_ids:["11","22"]
 * },
 * private_tags: {
 * tag_ids: ["33", "44"]
 * }
 * }
 * }
 */
interface Tags {
    /** Tags that require an additional permission in order to access them, normally not given to site members or visitors. */
    privateTags?: TagList;
    /** Tags that are exposed to anyone who has access to the labeled entity itself, including site members and visitors. */
    tags?: TagList;
}
interface TagList {
    /**
     * List of tag IDs
     * @maxSize 100
     * @maxLength 5
     */
    tagIds?: string[];
}
interface BulkUpdateBillableItemTagsRequest {
    /**
     * IDs of billable items which tags will be updated.
     * @minSize 1
     * @maxSize 100
     * @format GUID
     */
    billableItemIds?: string[];
    /** List of tags to assign. */
    assignTags?: Tags;
    /** List of tags to unassign. */
    unassignTags?: Tags;
}
interface BulkUpdateBillableItemTagsResponse {
    /**
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkUpdateBillableItemTagsResult[];
    bulkActionMetadata?: BulkActionMetadata;
}
interface ItemMetadata {
    /**
     * Item ID. Should always be available, unless it's impossible (for example, when failing to create an item).
     * @format GUID
     */
    _id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface BulkUpdateBillableItemTagsResult {
    itemMetadata?: ItemMetadata;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
interface BulkUpdateBillableItemTagsByFilterRequest {
    filter?: Record<string, any> | null;
    assignTags?: Tags;
    unassignTags?: Tags;
}
interface BulkUpdateBillableItemTagsByFilterResponse {
    /** @format GUID */
    jobId?: string;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface CreateBillableItemRequest {
    /** BillableItem to be created. */
    billableItem: BillableItem;
}
interface CreateBillableItemResponse {
    /** The created BillableItem. */
    billableItem?: BillableItem;
}
interface GetBillableItemRequest {
    /**
     * Billable item ID.
     * @format GUID
     */
    billableItemId: string;
}
interface GetBillableItemResponse {
    /** Requested billable item. */
    billableItem?: BillableItem;
}
interface UpdateBillableItemRequest {
    /** Billable item to update. May be partial. */
    billableItem: BillableItem;
}
interface UpdateBillableItemResponse {
    /** Updated billable item. */
    billableItem?: BillableItem;
}
interface DeleteBillableItemRequest {
    /**
     * Billable item ID to delete.
     * @format GUID
     */
    billableItemId: string;
}
interface DeleteBillableItemResponse {
}
interface QueryBillableItemsRequest {
    /** Query options. */
    query?: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryBillableItemsResponse {
    /** Requested billable items. */
    billableItems?: BillableItem[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface InternalQueryBillableItemsRequest {
    /** Query options. */
    query?: InternalCursorQuery;
}
interface InternalCursorQuery extends InternalCursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: InternalCursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
interface InternalCursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: InternalCursorPaging;
}
interface InternalCursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 10000
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface InternalQueryBillableItemsResponse {
    /** Requested billable items. */
    billableItems?: BillableItem[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
interface BulkCreateBillableItemsRequest {
    /**
     * List of billable items to create.
     * @minSize 1
     * @maxSize 100
     */
    billableItems: BillableItem[];
    /** Return created billable items in the response. */
    returnEntity?: boolean;
}
interface BulkCreateBillableItemsResponse {
    /**
     * List of billable items create operation results including metadata.
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkBillableItemResult[];
    /** Metadata regarding the bulk create operation. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkBillableItemResult {
    /** Billable item's create operation metadata. */
    itemMetadata?: ItemMetadata;
    /** Created billable item if `returnEntity` was set `true` in the request. */
    item?: BillableItem;
}
interface BulkUpdateBillableItemsRequest {
    /**
     * Billable items to update.
     * @minSize 1
     * @maxSize 100
     */
    billableItems: MaskedBillableItem[];
    /** Return updated billable items in the response. */
    returnEntity?: boolean;
}
interface MaskedBillableItem {
    /** Billable items to update. May be partial. */
    billableItem?: BillableItem;
}
interface BulkUpdateBillableItemsResponse {
    /**
     * Billable items update operation results including metadata.
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkUpdateBillableItemsResponseBulkBillableItemResult[];
    /** Metadata regarding the bulk update operation. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkUpdateBillableItemsResponseBulkBillableItemResult {
    /** Billable item's update operation metadata. */
    itemMetadata?: ItemMetadata;
    /** Updated billable item if `returnEntity` was set `true` in the request. */
    item?: BillableItem;
}
interface BulkDeleteBillableItemsRequest {
    /**
     * Billable item IDs to delete.
     * @minSize 1
     * @maxSize 100
     * @format GUID
     */
    billableItemIds: string[];
}
interface BulkDeleteBillableItemsResponse {
    /**
     * Billable items delete operation results including metadata.
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkDeleteBillableItemsResponseBulkBillableItemResult[];
    /** Metadata regarding the bulk delete operation. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkDeleteBillableItemsResponseBulkBillableItemResult {
    /** Billable item's delete operation metadata. */
    itemMetadata?: ItemMetadata;
}
interface V1BulkUpdateBillableItemTagsRequest {
    /**
     * IDs of billable items which tags will be updated.
     * @minSize 1
     * @maxSize 100
     * @format GUID
     */
    billableItemIds: string[];
    /** List of tags to assign. */
    assignTags?: Tags;
    /** List of tags to unassign. */
    unassignTags?: Tags;
}
interface V1BulkUpdateBillableItemTagsResponse {
    /**
     * Billable items update tags results including metadata.
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkUpdateBillableItemTagsResponseBulkUpdateBillableItemTagsResult[];
    /** Bulk update tags metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkUpdateBillableItemTagsResponseBulkUpdateBillableItemTagsResult {
    /** Billable item's update tags operation metadata. */
    itemMetadata?: ItemMetadata;
}
interface V1BulkUpdateBillableItemTagsByFilterRequest {
    /** Filter to select relevant billable items. */
    filter: Record<string, any> | null;
    /** List of tags to assign. */
    assignTags?: Tags;
    /** List of tags to unassign. */
    unassignTags?: Tags;
}
interface V1BulkUpdateBillableItemTagsByFilterResponse {
    /**
     * Job ID.
     * @format GUID
     */
    jobId?: string;
}
interface SearchBillableItemsRequest {
    /** Search options. */
    search?: CursorSearch;
}
interface CursorSearch extends CursorSearchPagingMethodOneOf {
    /**
     * Cursor pointing to page of results.
     * When requesting 'cursor_paging.cursor', no `filter`, `sort` or `search` can be provided.
     */
    cursorPaging?: CursorPaging;
    /** A filter object. See documentation [here](https://bo.wix.com/wix-docs/rnd/platformization-guidelines/api-query-language#platformization-guidelines_api-query-language_defining-in-protobuf) */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the form [{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]
     * @maxSize 10
     */
    sort?: Sorting[];
    /**
     * Aggregations | Faceted search: refers to a way to explore large amounts of data by displaying summaries about various partitions of the data and later allowing to narrow the navigation to a specific partition.
     * @maxSize 10
     */
    aggregations?: Aggregation[];
    /** Free text to match in searchable fields */
    search?: SearchDetails;
    /**
     * UTC offset or IANA time zone. Valid values are
     * ISO 8601 UTC offsets, such as +02:00 or -06:00,
     * and IANA time zone IDs, such as Europe/Rome
     *
     * Affects all filters and aggregations returned values.
     * You may override this behavior in a specific filter by providing
     * timestamps including time zone. e.g. `"2023-12-20T10:52:34.795Z"`
     * @maxLength 50
     */
    timeZone?: string | null;
}
/** @oneof */
interface CursorSearchPagingMethodOneOf {
    /**
     * Cursor pointing to page of results.
     * When requesting 'cursor_paging.cursor', no `filter`, `sort` or `search` can be provided.
     */
    cursorPaging?: CursorPaging;
}
interface Aggregation extends AggregationKindOneOf {
    /** Value aggregation */
    value?: ValueAggregation;
    /** Range aggregation */
    range?: RangeAggregation;
    /** Scalar aggregation */
    scalar?: ScalarAggregation;
    /** Date histogram aggregation */
    dateHistogram?: DateHistogramAggregation;
    /** Nested aggregation */
    nested?: NestedAggregation;
    /**
     * User-defined name of aggregation, should be unique, will appear in aggregation results
     * @maxLength 100
     */
    name?: string | null;
    /** Type of aggregation, client must provide matching aggregation field below */
    type?: AggregationTypeWithLiterals;
    /**
     * Field to aggregate by, use dot notation to specify json path
     * @maxLength 200
     */
    fieldPath?: string;
}
/** @oneof */
interface AggregationKindOneOf {
    /** Value aggregation */
    value?: ValueAggregation;
    /** Range aggregation */
    range?: RangeAggregation;
    /** Scalar aggregation */
    scalar?: ScalarAggregation;
    /** Date histogram aggregation */
    dateHistogram?: DateHistogramAggregation;
    /** Nested aggregation */
    nested?: NestedAggregation;
}
interface RangeBucket {
    /** Inclusive lower bound of the range. Required if to is not given */
    from?: number | null;
    /** Exclusive upper bound of the range. Required if from is not given */
    to?: number | null;
}
declare enum SortType {
    /** Should sort by number of matches */
    COUNT = "COUNT",
    /** Should sort by value of the field alphabetically */
    VALUE = "VALUE"
}
/** @enumType */
type SortTypeWithLiterals = SortType | 'COUNT' | 'VALUE';
declare enum SortDirection {
    /** Should sort in descending order */
    DESC = "DESC",
    /** Should sort in ascending order */
    ASC = "ASC"
}
/** @enumType */
type SortDirectionWithLiterals = SortDirection | 'DESC' | 'ASC';
declare enum MissingValues {
    /** Should missing values be excluded from the aggregation results */
    EXCLUDE = "EXCLUDE",
    /** Should missing values be included in the aggregation results */
    INCLUDE = "INCLUDE"
}
/** @enumType */
type MissingValuesWithLiterals = MissingValues | 'EXCLUDE' | 'INCLUDE';
interface IncludeMissingValuesOptions {
    /**
     * Can specify custom bucket name. Defaults are [string -> "N/A"], [int -> "0"], [bool -> "false"] ...
     * @maxLength 20
     */
    addToBucket?: string;
}
declare enum ScalarType {
    UNKNOWN_SCALAR_TYPE = "UNKNOWN_SCALAR_TYPE",
    /** Count of distinct values */
    COUNT_DISTINCT = "COUNT_DISTINCT",
    /** Minimum value */
    MIN = "MIN",
    /** Maximum value */
    MAX = "MAX"
}
/** @enumType */
type ScalarTypeWithLiterals = ScalarType | 'UNKNOWN_SCALAR_TYPE' | 'COUNT_DISTINCT' | 'MIN' | 'MAX';
interface ValueAggregation extends ValueAggregationOptionsOneOf {
    /** Options for including missing values */
    includeOptions?: IncludeMissingValuesOptions;
    /** Should sort by number of matches or value of the field */
    sortType?: SortTypeWithLiterals;
    /** Should sort in ascending or descending order */
    sortDirection?: SortDirectionWithLiterals;
    /** How many aggregations would you like to return? Can be between 1 and 250. 10 is the default. */
    limit?: number | null;
    /** Should missing values be included or excluded from the aggregation results. Default is EXCLUDE */
    missingValues?: MissingValuesWithLiterals;
}
/** @oneof */
interface ValueAggregationOptionsOneOf {
    /** Options for including missing values */
    includeOptions?: IncludeMissingValuesOptions;
}
declare enum NestedAggregationType {
    UNKNOWN_AGGREGATION_TYPE = "UNKNOWN_AGGREGATION_TYPE",
    /** An aggregation where result buckets are dynamically built - one per unique value */
    VALUE = "VALUE",
    /** An aggregation, where user can define set of ranges - each representing a bucket */
    RANGE = "RANGE",
    /** A single-value metric aggregation - e.g. min, max, sum, avg */
    SCALAR = "SCALAR",
    /** An aggregation, where result buckets are dynamically built - one per time interval (hour, day, week, etc.) */
    DATE_HISTOGRAM = "DATE_HISTOGRAM"
}
/** @enumType */
type NestedAggregationTypeWithLiterals = NestedAggregationType | 'UNKNOWN_AGGREGATION_TYPE' | 'VALUE' | 'RANGE' | 'SCALAR' | 'DATE_HISTOGRAM';
interface RangeAggregation {
    /**
     * List of range buckets, where during aggregation each entity will be placed in the first bucket where its value falls into based on provided range bounds
     * @maxSize 50
     */
    buckets?: RangeBucket[];
}
interface ScalarAggregation {
    /** Define the operator for the scalar aggregation */
    type?: ScalarTypeWithLiterals;
}
interface DateHistogramAggregation {
    /** Interval for date histogram aggregation */
    interval?: IntervalWithLiterals;
}
declare enum Interval {
    UNKNOWN_INTERVAL = "UNKNOWN_INTERVAL",
    /** Yearly interval */
    YEAR = "YEAR",
    /** Monthly interval */
    MONTH = "MONTH",
    /** Weekly interval */
    WEEK = "WEEK",
    /** Daily interval */
    DAY = "DAY",
    /** Hourly interval */
    HOUR = "HOUR",
    /** Minute interval */
    MINUTE = "MINUTE",
    /** Second interval */
    SECOND = "SECOND"
}
/** @enumType */
type IntervalWithLiterals = Interval | 'UNKNOWN_INTERVAL' | 'YEAR' | 'MONTH' | 'WEEK' | 'DAY' | 'HOUR' | 'MINUTE' | 'SECOND';
interface NestedAggregationItem extends NestedAggregationItemKindOneOf {
    /** Value aggregation */
    value?: ValueAggregation;
    /** Range aggregation */
    range?: RangeAggregation;
    /** Scalar aggregation */
    scalar?: ScalarAggregation;
    /** Date histogram aggregation */
    dateHistogram?: DateHistogramAggregation;
    /**
     * User-defined name of aggregation, should be unique, will appear in aggregation results
     * @maxLength 100
     */
    name?: string | null;
    /** Type of aggregation, client must provide matching aggregation field below */
    type?: NestedAggregationTypeWithLiterals;
    /**
     * Field to aggregate by, use dont notation to specify json path
     * @maxLength 200
     */
    fieldPath?: string;
}
/** @oneof */
interface NestedAggregationItemKindOneOf {
    /** Value aggregation */
    value?: ValueAggregation;
    /** Range aggregation */
    range?: RangeAggregation;
    /** Scalar aggregation */
    scalar?: ScalarAggregation;
    /** Date histogram aggregation */
    dateHistogram?: DateHistogramAggregation;
}
declare enum AggregationType {
    UNKNOWN_AGGREGATION_TYPE = "UNKNOWN_AGGREGATION_TYPE",
    /** An aggregation where result buckets are dynamically built - one per unique value */
    VALUE = "VALUE",
    /** An aggregation, where user can define set of ranges - each representing a bucket */
    RANGE = "RANGE",
    /** A single-value metric aggregation - e.g. min, max, sum, avg */
    SCALAR = "SCALAR",
    /** An aggregation, where result buckets are dynamically built - one per time interval (hour, day, week, etc.) */
    DATE_HISTOGRAM = "DATE_HISTOGRAM",
    /** Multi-level aggregation, where each next aggregation is nested within previous one */
    NESTED = "NESTED"
}
/** @enumType */
type AggregationTypeWithLiterals = AggregationType | 'UNKNOWN_AGGREGATION_TYPE' | 'VALUE' | 'RANGE' | 'SCALAR' | 'DATE_HISTOGRAM' | 'NESTED';
/** Nested aggregation expressed through a list of aggregation where each next aggregation is nested within previous one */
interface NestedAggregation {
    /**
     * Flattened list of aggregations, where each next aggregation is nested within previous one
     * @minSize 2
     * @maxSize 3
     */
    nestedAggregations?: NestedAggregationItem[];
}
interface SearchDetails {
    /** Defines how separate search terms in `expression` are combined */
    mode?: ModeWithLiterals;
    /**
     * Search term or expression
     * @maxLength 100
     */
    expression?: string | null;
    /**
     * Fields to search in. If empty - will search in all searchable fields. Use dot notation to specify json path
     * @maxLength 200
     * @maxSize 20
     */
    fields?: string[];
    /** Flag if should use auto fuzzy search (allowing typos by a managed proximity algorithm) */
    fuzzy?: boolean;
}
declare enum Mode {
    /** Any of the search terms must be present */
    OR = "OR",
    /** All search terms must be present */
    AND = "AND"
}
/** @enumType */
type ModeWithLiterals = Mode | 'OR' | 'AND';
interface SearchBillableItemsResponse {
    /** Requested billable items. */
    billableItems?: BillableItem[];
    /** Paging metadata. */
    pagingMetadata?: PagingMetadataV2;
    /** Response aggregation data. */
    aggregationData?: AggregationData;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface AggregationData {
    /**
     * key = aggregation name (as derived from search request)
     * @maxSize 10000
     */
    results?: AggregationResults[];
}
interface ValueAggregationResult {
    /**
     * Value of the field
     * @maxLength 100
     */
    value?: string;
    /** Count of entities with this value */
    count?: number;
}
interface RangeAggregationResult {
    /** Inclusive lower bound of the range */
    from?: number | null;
    /** Exclusive upper bound of the range */
    to?: number | null;
    /** Count of entities in this range */
    count?: number;
}
interface NestedAggregationResults extends NestedAggregationResultsResultOneOf {
    /** Value aggregation results */
    values?: ValueResults;
    /** Range aggregation results */
    ranges?: RangeResults;
    /** Scalar aggregation results */
    scalar?: AggregationResultsScalarResult;
    /**
     * User-defined name of aggregation, matches the one provided in request
     * @maxLength 100
     */
    name?: string;
    /** Type of aggregation that matches result */
    type?: AggregationTypeWithLiterals;
    /**
     * Field to aggregate by, matches the one provided in request
     * @maxLength 200
     */
    fieldPath?: string;
}
/** @oneof */
interface NestedAggregationResultsResultOneOf {
    /** Value aggregation results */
    values?: ValueResults;
    /** Range aggregation results */
    ranges?: RangeResults;
    /** Scalar aggregation results */
    scalar?: AggregationResultsScalarResult;
}
interface ValueResults {
    /**
     * List of value aggregations
     * @maxSize 250
     */
    results?: ValueAggregationResult[];
}
interface RangeResults {
    /**
     * List of ranges returned in same order as requested
     * @maxSize 50
     */
    results?: RangeAggregationResult[];
}
interface AggregationResultsScalarResult {
    /** Type of scalar aggregation */
    type?: ScalarTypeWithLiterals;
    /** Value of the scalar aggregation */
    value?: number;
}
interface NestedValueAggregationResult {
    /**
     * Value of the field
     * @maxLength 1000
     */
    value?: string;
    /** Nested aggregations */
    nestedResults?: NestedAggregationResults;
}
interface ValueResult {
    /**
     * Value of the field
     * @maxLength 1000
     */
    value?: string;
    /** Count of entities with this value */
    count?: number | null;
}
interface RangeResult {
    /** Inclusive lower bound of the range */
    from?: number | null;
    /** Exclusive upper bound of the range */
    to?: number | null;
    /** Count of entities in this range */
    count?: number | null;
}
interface ScalarResult {
    /** Value of the scalar aggregation */
    value?: number;
}
interface NestedResultValue extends NestedResultValueResultOneOf {
    /** Value aggregation result */
    value?: ValueResult;
    /** Range aggregation result */
    range?: RangeResult;
    /** Scalar aggregation result */
    scalar?: ScalarResult;
    /** Date histogram aggregation result */
    dateHistogram?: ValueResult;
}
/** @oneof */
interface NestedResultValueResultOneOf {
    /** Value aggregation result */
    value?: ValueResult;
    /** Range aggregation result */
    range?: RangeResult;
    /** Scalar aggregation result */
    scalar?: ScalarResult;
    /** Date histogram aggregation result */
    dateHistogram?: ValueResult;
}
interface Results {
    /** List of nested aggregations */
    results?: Record<string, NestedResultValue>;
}
interface DateHistogramResult {
    /**
     * Date in ISO 8601 format
     * @maxLength 100
     */
    value?: string;
    /** Count of documents in the bucket */
    count?: number;
}
interface GroupByValueResults {
    /**
     * List of value aggregations
     * @maxSize 1000
     */
    results?: NestedValueAggregationResult[];
}
interface DateHistogramResults {
    /**
     * List of date histogram aggregations
     * @maxSize 200
     */
    results?: DateHistogramResult[];
}
/**
 * Results of `NESTED` aggregation type in a flattened form
 * aggregations in resulting array are keyed by requested aggregation `name`.
 */
interface NestedResults {
    /**
     * List of nested aggregations
     * @maxSize 1000
     */
    results?: Results[];
}
interface AggregationResults extends AggregationResultsResultOneOf {
    /** Value aggregation results */
    values?: ValueResults;
    /** Range aggregation results */
    ranges?: RangeResults;
    /** Scalar aggregation results */
    scalar?: AggregationResultsScalarResult;
    /** Group by value aggregation results */
    groupedByValue?: GroupByValueResults;
    /** Date histogram aggregation results */
    dateHistogram?: DateHistogramResults;
    /** Nested aggregation results */
    nested?: NestedResults;
    /**
     * User-defined name of aggregation as derived from search request
     * @maxLength 100
     */
    name?: string;
    /** Type of aggregation that must match provided kind as derived from search request */
    type?: AggregationTypeWithLiterals;
    /**
     * Field to aggregate by as derived from search request
     * @maxLength 200
     */
    fieldPath?: string;
}
/** @oneof */
interface AggregationResultsResultOneOf {
    /** Value aggregation results */
    values?: ValueResults;
    /** Range aggregation results */
    ranges?: RangeResults;
    /** Scalar aggregation results */
    scalar?: AggregationResultsScalarResult;
    /** Group by value aggregation results */
    groupedByValue?: GroupByValueResults;
    /** Date histogram aggregation results */
    dateHistogram?: DateHistogramResults;
    /** Nested aggregation results */
    nested?: NestedResults;
}
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface BillableItemCreatedEnvelope {
    entity: BillableItem;
    metadata: EventMetadata;
}
interface BillableItemDeletedEnvelope {
    entity: BillableItem;
    metadata: EventMetadata;
}
interface BillableItemUpdatedEnvelope {
    entity: BillableItem;
    metadata: EventMetadata;
}
interface UpdateBillableItem {
    /**
     * Billable item ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the billable item is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the billable item.
     *
     * Ignored when creating a billable item.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the billable item was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the billable item was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * The name or title of the billable item. Used to identify the item on an invoice and display to customers.
     * @minLength 1
     * @maxLength 200
     */
    name?: string;
    /**
     * Detailed description of the billable item. Provides additional information about the product or service.
     * @minLength 1
     * @maxLength 600
     */
    description?: string | null;
    /**
     * Price of the billable item in decimal format with up to 4 decimal places.
     * Represents the base cost before taxes are applied. This is a required field when creating a new billable item.
     * @format DECIMAL_VALUE
     * @decimalValue options { gte:-1000000000000000, lte:1000000000000000, maxScale:4 }
     */
    price?: string;
    /**
     * Reference to a tax group that defines the tax rules applicable to this billable item.
     * Use the Tax Groups API to retrieve available tax groups for the business.
     * The tax group determines how taxes are calculated when this item is added to an invoice.
     * If not specified, the default tax rules for the business will apply.
     * See: https://dev.wix.com/docs/rest/business-solutions/e-commerce/tax/tax-groups/introduction
     * @format GUID
     */
    taxGroupId?: string | null;
    /**
     * The billable item image. Optional visual representation of the product or service.
     * Image must be uploaded to Wix Media Manager before referencing here.
     * Contains image ID, URL, dimensions, and alt text for accessibility.
     * To upload an image, use the Media Manager API or dashboard before creating/updating the BillableItem.
     */
    image?: string;
    /**
     * Custom field data for the billable item.
     * Extended fields must be configured in the app dashboard before they can be accessed with API calls.
     */
    extendedFields?: ExtendedFields;
    /** Tags. */
    tags?: Tags;
}
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
interface BillableItemsQueryResult extends QueryCursorResult {
    items: BillableItem[];
    query: BillableItemsQueryBuilder;
    next: () => Promise<BillableItemsQueryResult>;
    prev: () => Promise<BillableItemsQueryResult>;
}
interface BillableItemsQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    eq: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags', value: any) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ne: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags', value: any) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ge: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId', value: any) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    gt: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId', value: any) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    le: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId', value: any) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    lt: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId', value: any) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `string`.
     * @param string - String to compare against. Case-insensitive.
     * @documentationMaturity preview
     */
    startsWith: (propertyName: '_id' | 'name' | 'description' | 'price' | 'taxGroupId', value: string) => BillableItemsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasSome: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags', value: any[]) => BillableItemsQueryBuilder;
    /** @documentationMaturity preview */
    in: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags', value: any) => BillableItemsQueryBuilder;
    /** @documentationMaturity preview */
    exists: (propertyName: '_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags', value: boolean) => BillableItemsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    ascending: (...propertyNames: Array<'_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags'>) => BillableItemsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    descending: (...propertyNames: Array<'_id' | '_createdDate' | '_updatedDate' | 'name' | 'description' | 'price' | 'taxGroupId' | 'image' | 'tags'>) => BillableItemsQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object.
     * @documentationMaturity preview
     */
    limit: (limit: number) => BillableItemsQueryBuilder;
    /** @param cursor - A pointer to specific record
     * @documentationMaturity preview
     */
    skipTo: (cursor: string) => BillableItemsQueryBuilder;
    /** @documentationMaturity preview */
    find: () => Promise<BillableItemsQueryResult>;
}
interface BulkCreateBillableItemsOptions {
    /** Return created billable items in the response. */
    returnEntity?: boolean;
}
interface BulkUpdateBillableItemsOptions {
    /** Return updated billable items in the response. */
    returnEntity?: boolean;
}
interface BulkUpdateBillableItemTagsOptions {
    /** List of tags to assign. */
    assignTags?: Tags;
    /** List of tags to unassign. */
    unassignTags?: Tags;
}
interface BulkUpdateBillableItemTagsByFilterOptions {
    /** List of tags to assign. */
    assignTags?: Tags;
    /** List of tags to unassign. */
    unassignTags?: Tags;
}
interface BillableItemSearchSpec extends SearchSpec {
    aggregatable: [
        '_createdDate',
        '_id',
        '_updatedDate',
        'description',
        'name',
        'taxGroupId'
    ];
    paging: 'cursor';
    wql: [
        {
            operators: '*';
            fields: [
                '_createdDate',
                '_id',
                '_updatedDate',
                'description',
                'name',
                'taxGroupId'
            ];
            sort: 'BOTH';
        }
    ];
}
type CommonSearchWithEntityContext = Search<BillableItem, BillableItemSearchSpec>;
type BillableItemSearch = {
    /**
    Cursor pointing to page of results.
    When requesting 'cursor_paging.cursor', no `filter`, `sort` or `search` can be provided.
    */
    cursorPaging?: {
        /**
      Maximum number of items to return in the results.
      @max: 100
      */
        limit?: NonNullable<CommonSearchWithEntityContext['cursorPaging']>['limit'] | null;
        /**
      Pointer to the next or previous page in the list of results.
    
      Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
      Not relevant for the first request.
      @maxLength: 16000
      */
        cursor?: NonNullable<CommonSearchWithEntityContext['cursorPaging']>['cursor'] | null;
    };
    /**
    A filter object. See documentation [here](https://bo.wix.com/wix-docs/rnd/platformization-guidelines/api-query-language#platformization-guidelines_api-query-language_defining-in-protobuf)
    */
    filter?: CommonSearchWithEntityContext['filter'] | null;
    /**
    Sort object in the form [{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]
    @maxSize: 10
    */
    sort?: {
        /**
      Name of the field to sort by.
      @maxLength: 512
      */
        fieldName?: NonNullable<CommonSearchWithEntityContext['sort']>[number]['fieldName'];
        /**
      Sort order.
      */
        order?: NonNullable<CommonSearchWithEntityContext['sort']>[number]['order'];
    }[];
    /**
    Aggregations | Faceted search: refers to a way to explore large amounts of data by displaying summaries about various partitions of the data and later allowing to narrow the navigation to a specific partition.
    @maxSize: 10
    */
    aggregations?: {
        /**
      Value aggregation
      */
        value?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['value'];
        /**
      Range aggregation
      */
        range?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['range'];
        /**
      Scalar aggregation
      */
        scalar?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['scalar'];
        /**
      Date histogram aggregation
      */
        dateHistogram?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['dateHistogram'];
        /**
      Nested aggregation
      */
        nested?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['nested'];
        /**
      User-defined name of aggregation, should be unique, will appear in aggregation results
      @maxLength: 100
      */
        name?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['name'] | null;
        /**
      Type of aggregation, client must provide matching aggregation field below
      */
        type?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['type'];
        /**
      Field to aggregate by, use dot notation to specify json path
      @maxLength: 200
      */
        fieldPath?: NonNullable<CommonSearchWithEntityContext['aggregations']>[number]['fieldPath'];
    }[];
    /**
    Free text to match in searchable fields
    */
    search?: {
        /**
      Defines how separate search terms in `expression` are combined
      */
        mode?: NonNullable<CommonSearchWithEntityContext['search']>['mode'];
        /**
      Search term or expression
      @maxLength: 100
      */
        expression?: NonNullable<CommonSearchWithEntityContext['search']>['expression'] | null;
        /**
      Fields to search in. If empty - will search in all searchable fields. Use dot notation to specify json path
      @maxLength: 200,
      @maxSize: 20
      */
        fields?: NonNullable<CommonSearchWithEntityContext['search']>['fields'];
        /**
      Flag if should use auto fuzzy search (allowing typos by a managed proximity algorithm)
      */
        fuzzy?: NonNullable<CommonSearchWithEntityContext['search']>['fuzzy'];
    };
    /**
    UTC offset or IANA time zone. Valid values are
    ISO 8601 UTC offsets, such as +02:00 or -06:00,
    and IANA time zone IDs, such as Europe/Rome
  
    Affects all filters and aggregations returned values.
    You may override this behavior in a specific filter by providing
    timestamps including time zone. e.g. `"2023-12-20T10:52:34.795Z"`
    @maxLength: 50
    */
    timeZone?: CommonSearchWithEntityContext['timeZone'] | null;
};

export { type UpdateBillableItemRequest as $, AggregationType as A, type BillableItem as B, type BulkUpdateBillableItemTagsByFilterRequest as C, type BulkUpdateBillableItemTagsByFilterResponse as D, type ExtendedFields as E, type DomainEvent as F, type DomainEventBodyOneOf as G, type EntityCreatedEvent as H, Interval as I, type EntityUpdatedEvent as J, type EntityDeletedEvent as K, type ActionEvent as L, type MaskedBillableItem as M, NestedAggregationType as N, type MessageEnvelope as O, type IdentificationData as P, type IdentificationDataIdOneOf as Q, type RestoreInfo as R, type SearchBillableItemsResponse as S, type Tags as T, type UpdateBillableItem as U, type V1BulkUpdateBillableItemTagsResponse as V, WebhookIdentityType as W, type CreateBillableItemRequest as X, type CreateBillableItemResponse as Y, type GetBillableItemRequest as Z, type GetBillableItemResponse as _, type BillableItemsQueryBuilder as a, type BaseEventMetadata as a$, type UpdateBillableItemResponse as a0, type DeleteBillableItemRequest as a1, type DeleteBillableItemResponse as a2, type QueryBillableItemsRequest as a3, type CursorQuery as a4, type CursorQueryPagingMethodOneOf as a5, type Sorting as a6, type CursorPaging as a7, type QueryBillableItemsResponse as a8, type CursorPagingMetadata as a9, type DateHistogramAggregation as aA, type NestedAggregationItem as aB, type NestedAggregationItemKindOneOf as aC, type NestedAggregation as aD, type SearchDetails as aE, type PagingMetadataV2 as aF, type AggregationData as aG, type ValueAggregationResult as aH, type RangeAggregationResult as aI, type NestedAggregationResults as aJ, type NestedAggregationResultsResultOneOf as aK, type ValueResults as aL, type RangeResults as aM, type AggregationResultsScalarResult as aN, type NestedValueAggregationResult as aO, type ValueResult as aP, type RangeResult as aQ, type ScalarResult as aR, type NestedResultValue as aS, type NestedResultValueResultOneOf as aT, type Results as aU, type DateHistogramResult as aV, type GroupByValueResults as aW, type DateHistogramResults as aX, type NestedResults as aY, type AggregationResults as aZ, type AggregationResultsResultOneOf as a_, type Cursors as aa, type InternalQueryBillableItemsRequest as ab, type InternalCursorQuery as ac, type InternalCursorQueryPagingMethodOneOf as ad, type InternalCursorPaging as ae, type InternalQueryBillableItemsResponse as af, type BulkCreateBillableItemsRequest as ag, type BulkBillableItemResult as ah, type BulkUpdateBillableItemsRequest as ai, type BulkUpdateBillableItemsResponseBulkBillableItemResult as aj, type BulkDeleteBillableItemsRequest as ak, type BulkDeleteBillableItemsResponseBulkBillableItemResult as al, type V1BulkUpdateBillableItemTagsRequest as am, type BulkUpdateBillableItemTagsResponseBulkUpdateBillableItemTagsResult as an, type V1BulkUpdateBillableItemTagsByFilterRequest as ao, type SearchBillableItemsRequest as ap, type CursorSearch as aq, type CursorSearchPagingMethodOneOf as ar, type Aggregation as as, type AggregationKindOneOf as at, type RangeBucket as au, type IncludeMissingValuesOptions as av, type ValueAggregation as aw, type ValueAggregationOptionsOneOf as ax, type RangeAggregation as ay, type ScalarAggregation as az, type BulkCreateBillableItemsOptions as b, type EventMetadata as b0, type BillableItemsQueryResult as b1, type BillableItemSearchSpec as b2, type BulkCreateBillableItemsResponse as c, type BulkUpdateBillableItemsOptions as d, type BulkUpdateBillableItemsResponse as e, type BulkDeleteBillableItemsResponse as f, type BulkUpdateBillableItemTagsOptions as g, type BulkUpdateBillableItemTagsByFilterOptions as h, type V1BulkUpdateBillableItemTagsByFilterResponse as i, type BillableItemSearch as j, type BillableItemCreatedEnvelope as k, type BillableItemDeletedEnvelope as l, type BillableItemUpdatedEnvelope as m, SortOrder as n, SortType as o, SortDirection as p, MissingValues as q, ScalarType as r, Mode as s, type TagList as t, type BulkUpdateBillableItemTagsRequest as u, type BulkUpdateBillableItemTagsResponse as v, type ItemMetadata as w, type ApplicationError as x, type BulkUpdateBillableItemTagsResult as y, type BulkActionMetadata as z };
